\NeedsTeXFormat{LaTeX2e}[1994/06/01]
\ProvidesClass{dgfs2017}[2016/06/28 v.1.0 Class for DGfS 2017.]

%%%%%%%%%%%%%% DISCLAIMER %%%%%%%%%%%%%%%
%%% Based on macros defined for DGfS 2016 by Constantin Freytag (Uni Konstanz)
%%% Based on macros defined for Semantics and Pragmatics by Kai von Fintel (MIT)
%%% Based on macros defined for Sinn & Bedeutung 15 by Ingo Reich (Uni Saarland)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% dgfs2017 options, adapted from sp.cls %%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{scrbook}}

\newcommand{\@sizeoption@err}{\ClassError{dgfs2017}
  {Cannot use size option \CurrentOption} 
  {The dgfs2017 class requires (and automatically loads) 9pt text}}

\DeclareOption{12pt}{\@sizeoption@err}
\DeclareOption{11pt}{\@sizeoption@err}
\DeclareOption{10pt}{\@sizeoption@err}

\newcommand{\@psizeoption@err}{\ClassError{dgfs2017}
  {Cannot use paper size option \CurrentOption} 
  {The dgfs2017 class requires (and automatically loads) A5 paper}}

\DeclareOption{a4paper}{\@psizeoption@err}
\DeclareOption{b5paper}{\@psizeoption@err}
\DeclareOption{letterpaper}{\@psizeoption@err}
\DeclareOption{legalpaper}{\@psizeoption@err}
\DeclareOption{executivepaper}{\@psizeoption@err}
\DeclareOption{landscape}{\@psizeoption@err}

\ProcessOptions\relax
\LoadClass[a5paper,fontsize=9pt, index=toc, headings=small, DIV=12, BCOR=7mm,draft=false]{scrbook}

%%% Preambel file for the DGfS booklet %%%%
%% here all packages will be loaded %%%

\usepackage[safe]{tipa} %% must be loaded before fontspec to avoid
                        %% redefinition problem

%%%% FONT and GENERAL
%\usepackage[no-sscript]{xltxtra}%% font options for XeTeX including the XeLaTeX logo, automatically loads the fontspec package
%%\usepackage{fontspec}
%\setmainfont{Skolar PE} %% serif font
%\setsansfont{Skolar Sans PE} %% sans serif (grotesk) font
%\usepackage{polyglossia}
%\setmainlanguage{german}
%\setotherlanguage{english}
\usepackage[utf8]{inputenc}
\usepackage[T1]{fontenc}
\usepackage[english,german]{babel}
%\usepackage{microtype}


\usepackage[german=quotes,%% german quotes' style 
english=american,%% english quotes' style
autostyle=true%% automatic switch of qoutes with polyglossias
              %% language environments
]{csquotes}




%% GRAPHICS %%
%%%%%%%%%%%%%%%%%%%%
\usepackage{graphicx}
%% set the paths to the folders where to find the graphics files
\graphicspath{{graphics/}
{graphics/colored/} %% for the digital version
% {graphics/bw/} %% for the printed version 
{Anzeigen/}
{sponsoren_logos/colored/} %% for the digital version
% {sponsoren_logos/bw/} %% for the printed version
{sponsoren_logos/}}

\usepackage{wrapfig}%% allows text to float around figures
\usepackage{pdfpages}%% allows the insertion of full pdf pages as document pages (advertisements)


%% MARKUP %%
%%%%%%%%%%%%%%%%%%%%
\usepackage{xcolor,lipsum}
%%%% custom color definitions 
%% requires the "color"or "xcolor" package respectively
\definecolor{navy}{RGB}{0,0,128}      %% navy blue -- only necessary for certain hyperref options
%
\usepackage[normalem]{ulem}


%% LINGUISTICS %%
%%%%%%%%%%%%%%%%%%%%
\IfFileExists{stmaryrd.sty}%
   {\RequirePackage{stmaryrd}}%
   {\newcommand{\llbracket}{\ensuremath{\left [\!\left [}}%
     \newcommand{\rrbracket}{\ensuremath{\right ]\!\right ]}}}
\IfFileExists{cgloss4e.sty}%
	{\RequirePackage{cgloss4e}}
	{\newcommand{\gll}{}\newcommand{\glll}{}\newcommand{\trans}{}}
\IfFileExists{linguex.sty}%
	{\RequirePackage{linguex}
	\setlength{\Exindent}{0pt}
	\setlength{\Exlabelwidth}{0pt}
	\setlength{\Exlabelsep}{7.5mm}
	\setlength{\SubExleftmargin}{5mm}
	\def\refdash{}
	\def\firstrefdash{}
	\setlength{\Extopsep}{6pt}
	\let\eachwordtwo=\it
	\let\eachwordthree=\it}
	{\newcommand{\ex.}{}\newcommand{\exg.}{}%
	 \newcommand{\a.}{}\newcommand{\b.}{}\newcommand{\c.}{}}
\IfFileExists{cgloss.sty}%
	{\RequirePackage{cgloss}}{}
\IfFileExists{qtree.sty}%
	{\RequirePackage[nocenter]{qtree}%
	\linethickness{.7pt}}{}


%% SYMBOLS %%
%%%%%%%%%%%%%%%%%%%%
\usepackage{amsfonts}%% mathfonts symbols for mathematical formulas
\usepackage{marvosym,%% dingbats- symbol for info and bicycle
pifont}%% dingbats - pencil symbol for Notizen
%\usepackage{textcomp}%% provides denotation brackets



%% LAYOUT %%
%%%%%%%%%%%%%%%%%%%%
\usepackage{scrlayer-scrpage}%% packages for header and
                                %% footer in the KOMA-class
%\usepackage{paralist}
\usepackage{booktabs}%% nice lines for tabulars
\usepackage{tabularx}%% tabulars with a fixed width
\usepackage{array}%% more functions for arrays and tabulars
\usepackage{longtable}%% long tables that include page breaks
\usepackage{colortbl}%% colored tabulars
\usepackage{setspace}%% easily change linespreading
\usepackage{marginnote}%% more flexible margins
	\renewcommand*{\marginfont}{\footnotesize\sffamily}
\usepackage{multirow}%% table cells that span several rows
\usepackage[inline]{enumitem} %% provides functionality to define new
                              %% list environments, such as the
                              %% referencelist 
%% "thumb" package loaded above for incompatibility reasons 
\usepackage{noindentafter} %% needed to suppress the indentation after
                           %% the custom defined outline commands
\usepackage{chngcntr}%% change counters
\counterwithout{figure}{section}%% number figures per section (agabstract)


%% FUNCTIONALITY %%
%%%%%%%%%%%%%%%%%%%%
\usepackage{ifthen}%% provides if-loops
\usepackage{makeidx}%% make indices
%\usepackage[width=154truemm,height=216truemm,center,cam]{crop}%% provides crop marks for printing maschines -- centering the logical page (A5-148mm × 210mm) on paper that has 3mm margins all around with simple crop marks (cam)
\usepackage{rotating}%% print sideways tables 	


\makeindex%% takes care of automatic indexation


%%%%%%%%%%%%%%%%%%%%%%%
%%% metadata begin  %%%
%%%%%%%%%%%%%%%%%%%%%%%

\usepackage[%extension=pdf,                     % AUSKOMMENTIERT FÜR DRUCK; FÜR ONLINE WIEDER REINNEHMEN [FH]
            %hyperref=true,                     % Option fuer Biblatex-Paket?
            %                                     Ergibt bei hyperref
            %                                     folgende Fehlermeldung: 
            %                                     Package xkeyval Error:
            %                                     `hyperref' undefined in families `Hyp'.[FH] 
            %                                     option required to work with dvips
            % dvips=true,                        % creates ps file that can be
            %                                     inputted to ps2pdf
            %                                     Gleiche Fehlermeldung wie fuer
            %                                     hyperref=true [FH]
            colorlinks=true,                    % links in colored font, not boxed %% not in the print version
           citecolor=navy,                     % bibliography link color -- see \definecolor  %% not in the print version 
           linkcolor=navy,                     % internal link color -- see \definecolor  %% not in the print version
           urlcolor=navy,                      % href and mailto link color -- see \definecolor %% not in the print version
%           allcolors=black,                     % bibliography link color -- see \definecolor  %% for the print version 
           breaklinks=true]                    % break links between lines, if necessary]
          {hyperref}
\hypersetup{%pdflang={de, en},
           pdftitle={DGfS 2017 Saarbrcken: Tagungsband},
           pdfauthor={Rauth, Reich},
           pdfsubject={Abstract and information booklet for DGfS 2017, Saarbrcken}}

%%%%%%%%%%%%%%%%%%%%
%%% metadata end %%%
%%%%%%%%%%%%%%%%%%%%





%%%%%%%%%%%%%%%%%%%
%%% other stuff %%%
%%%%%%%%%%%%%%%%%%%

\renewcommand{\baselinestretch}{1.05}
\pagenumbering{arabic}

%%%%%%%%%%%%%%%%% title & authors %%%%%%%%%%%%%%%%%%%%%%%
% partly adapted from sp.cls and acm.cls

\newlength\authorlength
\setlength{\authorlength}{1\textwidth}
\newcount\aucount
\newcount\originalaucount
\gdef\numberofauthors#1{\global\aucount=#1
\ifnum\aucount>3\global\originalaucount=\aucount \global\aucount=1\fi%
\ifnum\aucount=0\global\originalaucount=\aucount \global\aucount=1\fi}

\gdef\checkauthornumber{%
\ifnum\aucount=1\global \gdef\secondaddr{} \gdef\thirdaddr{} 
	\setlength{\authorlength}{.96\textwidth}\fi
\ifnum\aucount=2\global \gdef\thirdaddr{} 
	\setlength{\authorlength}{.48\textwidth}\fi
\ifnum\aucount=3\global 
	\setlength{\authorlength}{.32\textwidth}\fi
	}

\renewcommand*{\title}[2][]{\gdef\@shorttitle{#1}\gdef\@title{#2}}
\renewcommand*{\author}[2][]{\gdef\@shortauthor{#1}\gdef\@author{#2}}
\newcommand*{\shortauthor}[1]{\gdef\@shortauthor{#1}}
\newcommand*{\firstauthorfirstname}[2][]{\gdef\@shortfirstauthorfirstname{#1}\gdef\@firstauthorfirstname{#2}}\firstauthorfirstname[]{}
\newcommand*{\firstauthorlastname}[2][]{\gdef\@shortfirstauthorlastname{#1}\gdef\@firstauthorlastname{#2}}\firstauthorlastname[]{}
\newcommand*{\secondauthorfirstname}[2][]{\gdef\@shortsecondauthorfirstname{#1}\gdef\@secondauthorfirstname{#2}}\secondauthorfirstname[]{}
\newcommand*{\secondauthorlastname}[2][]{\gdef\@shortsecondauthorlastname{#1}\gdef\@secondauthorlastname{#2}}\secondauthorlastname[]{}
\newcommand*{\thirdauthorfirstname}[2][]{\gdef\@shortthirdauthorfirstname{#1}\gdef\@thirdauthorfirstname{#2}}\thirdauthorfirstname[]{}
\newcommand*{\thirdauthorlastname}[2][]{\gdef\@shortthirdauthorlastname{#1}\gdef\@thirdauthorlastname{#2}}\thirdauthorlastname[]{}
\newcommand*{\firstaff}[2][]{\gdef\@shortfirstaff{#1}\gdef\@firstaff{#2}}\firstaff[]{}
\newcommand*{\secondaff}[2][]{\gdef\@shortsecondaff{#1}\gdef\@secondaff{#2}}\secondaff[]{}
\newcommand*{\thirdaff}[2][]{\gdef\@shortthirdaff{#1}\gdef\@thirdaff{#2}}\thirdaff[]{}
\newcommand*{\firstmail}[2][]{\gdef\@shortfirstmail{#1}\gdef\@firstmail{#2}}\firstmail[]{}
\newcommand*{\secondmail}[2][]{\gdef\@shortsecondmail{#1}\gdef\@secondmail{#2}}\secondmail[]{}
\newcommand*{\thirdmail}[2][]{\gdef\@shortthirdmail{#1}\gdef\@thirdmail{#2}}\thirdmail[]{}

\newcommand*{\firstaddr}{%
\begin{minipage}[t]{\authorlength}
\centering
\@firstauthorfirstname~\@firstauthorlastname\index{\@firstauthorlastname,~\@firstauthorfirstname}\\
\textit{\@firstaff}\\[2pt]
{\footnotesize\href{mailto:\@firstmail}{\@firstmail}}
\end{minipage}
}
%
\newcommand*{\secondaddr}{%
\begin{minipage}[t]{\authorlength}
\centering
\@secondauthorfirstname~\@secondauthorlastname\index{\@secondauthorlastname,~\@secondauthorfirstname}\\
\textit{\@secondaff}\\[2pt]
{\footnotesize\href{mailto:\@secondmail}{\@secondmail}}
\end{minipage}
}
%
\newcommand*{\thirdaddr}{%
\begin{minipage}[t]{\authorlength}
\centering
\@thirdauthorfirstname~\@thirdauthorlastname\index{\@thirdauthorlastname,~\@thirdauthorfirstname}\\
\textit{\@thirdaff}\\[2pt]
{\footnotesize\href{mailto:\@thirdmail}{\@thirdmail}}\vfill
\end{minipage}
}
%
\newcommand*{\talkday}{Tag}
\newcommand*{\talkdate}{Datum}
\newcommand*{\talktime}{Zeit}
\newcommand*{\talkroom}{Raum}

% Adapted from JMLR.
\renewcommand{\maketitle}{%
  \par
  \begingroup
  \renewcommand{\thefootnote}{\fnsymbol{footnote}}
  \@maketitle\@thanks
  \setcounter{footnote}{0}
  \endgroup
  \let\maketitle\relax \let\@maketitle\relax
  \gdef\@thanks{}
  \let\thanks\relax%
}

% Adapted from salt.cls.
\newskip\onelineskip 
\onelineskip=\baselineskip 
\advance\onelineskip by0pt plus 4pt minus 2pt

\def\@maketitle{%
	\newpage
	\thispagestyle{plain}
  \vbox{\hsize\textwidth%
    \linewidth\hsize%
    \par\noindent%
    \rule{\textwidth}{1.25pt}%
    \begin{center}
    {\usekomafont{title}{\large\@title}}%
    \end{center}
    \vskip-.5em
    \rule{\textwidth}{1.25pt}%
        \vskip 1em
%    \addsec{\@title}%
%    \vspace*{14pt}%
%    \centering
%    \large\textbf{\sffamily\@title}\@@par
%    \normalsize
%    \let\par\@empty
%    \vskip\onelineskip
    \checkauthornumber
    \marginnote{\footnotesize \talkday\\ \talkdate\\ \talktime\\ \talkroom}%
    \hbox{\firstaddr\secondaddr\thirdaddr}
    \vskip\onelineskip\noindent
  }%
}

%%% macro for the references
\newcommand{\referencelistheading}{Literatur}%% heading German by
                                %% default
\gappto\captionsenglish{\renewcommand{\referencelistheading}{References}}%% add on for the english heading
%% requires the package enumitem
\newenvironment{referencelist}
{\begin{spacing}{1.1}%
\vspace{1em}%
\noindent%
%% Heading
{\footnotesize%
\sffamily%
\bfseries%
\referencelistheading%% heading content
:} %% End of heading
% Content-markup
\footnotesize%
\noindent%
\begin{itemize*}[itemsep=1em]}
%% CONTENT
{\end{itemize*}\end{spacing}}

\newcounter{abstractnumber}
\setcounter{abstractnumber}{0}
\newenvironment{abstract}{%
	\refstepcounter{abstractnumber}
	\clearpage
	%\setcounter{section}{0}
	\label{begin\theabstractnumber}
      }%
     {\label{end\theabstractnumber}}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% preamble ends --- document begins %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
